==> wasabiD-0.2.92.tgz: package/Base/Form/Radio.jsx <==
/**
 * Created by zhiyongwang on 2016-04-01.
 * 单选组件
 */
require("../../sass/Base/Form/Check.scss");
let React=require("react");
let alogUtil=require("../../libs/alogUtil.js");
let Radio=React.createClass({
    PropTypes:{
        name: React.PropTypes.string.isRequired,//对应表单name属性，用于提交
        label:React.PropTypes.string,//描述文字
        placeholder:React.PropTypes.string,//输入框内的提示文字
        valueField: React.PropTypes.string,//数据字段值名称
        textField:React.PropTypes.string,//数据字段文本名称
        value:React.PropTypes.string,//默认value值，
        text:React.PropTypes.string,//默认text值
        className:React.PropTypes.string,//附加新式
        readonly:React.PropTypes.bool,//是否只读,
        hide:React.PropTypes.hide,//是否隐藏 :
        url:React.PropTypes.string,//ajax的后台地址
        backSource:React.PropTypes.string,//ajax的返回的数据源中哪个属性作为数据源,为null时直接后台返回的数据作为数据源
        data:React.PropTypes.string,//数据源
        onSelect: React.PropTypes.func,//选中后的事件，回传，value,与text
        onlyline:React.PropTypes.bool,//是否只占一行

    },
    getDefaultProps:function() {
        return{
            label:"",
            placeholder:"",
            valueField:"value",
            textField:"text",
            value:"",
            text:"",
            url:null,
            backSource:null,
            readonly:false,
            className:"",
            hide:false,
            data:[],
            onSelect:null,
            onlyline:false,
        };
    },
    getInitialState:function() {
        return {
            data:(this.props.data),
            value:this.props.value,
            text:this.props.text,
            readonly:this.props.readonly,
        }
    },
    componentWillReceiveProps:function(nextProps) {
        this.setState({
            value: nextProps.value,
            text: nextProps.text,
            readonly:nextProps.readonly,
        })
        if(nextProps.data!=null&&nextProps.data.length>0)
        {
            this.setState({
                data:alogUtil.clone(nextProps.data)
            })
        }
    },
    componentWillMount:function()
    {//如果指定url,先查询数据再绑定
        if(this.props.url!=null)
        {
            var fetchmodel=new FetchModel(this.props.url,this.loadSuccess)
            alogUtil.fetch.get(fetchmodel);
        }
    },

    loadSuccess:function(data)
    {//数据加载成功
        var realdata=data;
        if(this.props.backSource==null) {
        }else {
            realData=alogUtil.getSource(data,this.props.backSource);
        }
        this.setState({
            data:realData,
        })
    },
    changeHandler:function(event)
    {//一害绑定，但不处理

    },

    onSelect:function(value,text)
    {//选中事件
        if(this.state.readonly)
        {
            return;
        }
        this.setState({
            value:value,
            text:text,
        });

        if( this.props.onSelect!=null)
        {
            this.props.onSelect(value,text,this.props.name);
        }
    },
    render:function() {
            var control;
        let  props=
        {
            readOnly:this.state.readonly==true?"readonly":null,
        }
        if(this.state.data)
        {
            if(this.props.onlyline)
            {

                control= this.state.data.map((child, i)=> {
                    var textFeild=child[this.props.textField];
                    if(this.props.textAutos!=null)
                    {
                        if(this.props.textAutos[i])
                        {
                            textFeild=this.props.textAutos[i];
                        }

                    }

                    return(
                        <div key={i} className="rodio-onlyline">
                            <div {...props}  className={"radio-btn "+(this.state.value.toString()==child[this.props.valueField]?"checkedRadio":"")} onClick={this.onSelect.bind(this,child[this.props.valueField],child[this.props.textField])}><i>
                                <input type="radio"
                                       id={this.props.name+child[this.props.valueField]}
                                       value={child[this.props.valueField]}
                                       onChange={this.changeHandler} {...props}>
                                </input>
                            </i></div><div className="radiotext">
                            {textFeild}

                        </div></div>
                    );})

            }
            else
            {
                control= this.state.data.map((child, i)=> {
                    var textFeild=child[this.props.textField];
                    if(this.props.textAutos!=null)
                    {
                        if(this.props.textAutos[i])
                        {
                            textFeild=this.props.textAutos[i];
                        }

                    }
                    return(
                        <li key={i} >
                            <div {...props} className={"radio-btn "+((this.state.value&&this.state.value==child[this.props.valueField])?"checkedRadio":"")} onClick={this.onSelect.bind(this,child[this.props.valueField],child[this.props.textField])}><i>
                                <input type="radio"
                                       id={this.props.name+child[this.props.valueField]}
                                       value={child[this.props.valueField]}
                                       onChange={this.changeHandler}
                                    {...props}
                                >
                                </input>
                            </i></div><div className="radiotext">{textFeild}</div></li>
                    );})
            }


        }

        if(this.props.onlyline)
        {
            return (

                <div >
                    {
                        control
                    }
                </div>
            )
        }
        else
        {
            return (

                <ul className="checkul">
                    {
                        control
                    }
                </ul>
            )
        }


    }

});
module.exports=Radio;

==> wasabiD-0.2.983.tgz: package/Base/Form/Radio.jsx <==
/**
 * Created by zhiyongwang on 2016-04-01.
 * 单选组件
 */
require("../../sass/Base/Form/Check.scss");
let React=require("react");
let unit=require("../../libs/unit.js");
let Radio=React.createClass({
    PropTypes:{
        name: React.PropTypes.string.isRequired,//对应表单name属性，用于提交
        label:React.PropTypes.string,//描述文字
        placeholder:React.PropTypes.string,//输入框内的提示文字
        valueField: React.PropTypes.string,//数据字段值名称
        textField:React.PropTypes.string,//数据字段文本名称
        value:React.PropTypes.string,//默认value值，
        text:React.PropTypes.string,//默认text值
        className:React.PropTypes.string,//附加新式
        readonly:React.PropTypes.bool,//是否只读,
        hide:React.PropTypes.hide,//是否隐藏 :
        url:React.PropTypes.string,//ajax的后台地址
        backSource:React.PropTypes.string,//ajax的返回的数据源中哪个属性作为数据源,为null时直接后台返回的数据作为数据源
        data:React.PropTypes.string,//数据源
        onSelect: React.PropTypes.func,//选中后的事件，回传，value,与text
        onlyline:React.PropTypes.bool,//是否只占一行

    },
    getDefaultProps:function() {
        return{
            label:"",
            placeholder:"",
            valueField:"value",
            textField:"text",
            value:"",
            text:"",
            url:null,
            backSource:null,
            readonly:false,
            className:"",
            hide:false,
            data:[],
            onSelect:null,
            onlyline:false,
        };
    },
    getInitialState:function() {
        return {
            data:(this.props.data),
            value:this.props.value,
            text:this.props.text,
            readonly:this.props.readonly,
        }
    },
    componentWillReceiveProps:function(nextProps) {
        this.setState({
            value: nextProps.value,
            text: nextProps.text,
            readonly:nextProps.readonly,
        })
        if(nextProps.data!=null&&nextProps.data.length>0)
        {
            this.setState({
                data:unit.clone(nextProps.data)
            })
        }
    },
    componentWillMount:function()
    {//如果指定url,先查询数据再绑定
        if(this.props.url!=null)
        {
            var fetchmodel=new FetchModel(this.props.url,this.loadSuccess)
            unit.fetch.get(fetchmodel);
        }
    },

    loadSuccess:function(data)
    {//数据加载成功
        var realdata=data;
        if(this.props.backSource==null) {
        }else {
            realData=unit.getSource(data,this.props.backSource);
        }
        this.setState({
            data:realData,
        })
    },
    changeHandler:function(event)
    {//一害绑定，但不处理

    },

    onSelect:function(value,text)
    {//选中事件
        if(this.state.readonly)
        {
            return;
        }
        this.setState({
            value:value,
            text:text,
        });

        if( this.props.onSelect!=null)
        {
            this.props.onSelect(value,text,this.props.name);
        }
    },
    render:function() {
            var control;
        let  props=
        {
            readOnly:this.state.readonly==true?"readonly":null,
        }
        if(this.state.data)
        {
            if(this.props.onlyline)
            {

                control= this.state.data.map((child, i)=> {
                    var textFeild=child[this.props.textField];
                    if(this.props.textAutos!=null)
                    {
                        if(this.props.textAutos[i])
                        {
                            textFeild=this.props.textAutos[i];
                        }

                    }

                    return(
                        <div key={i} className="rodio-onlyline">
                            <div {...props}  className={"radio-btn "+(this.state.value.toString()==child[this.props.valueField]?"checkedRadio":"")} onClick={this.onSelect.bind(this,child[this.props.valueField],child[this.props.textField])}><i>
                                <input type="radio"
                                       id={this.props.name+child[this.props.valueField]}
                                       value={child[this.props.valueField]}
                                       onChange={this.changeHandler} {...props}>
                                </input>
                            </i></div><div className="radiotext">
                            {textFeild}

                        </div></div>
                    );})

            }
            else
            {
                control= this.state.data.map((child, i)=> {
                    var textFeild=child[this.props.textField];
                    if(this.props.textAutos!=null)
                    {
                        if(this.props.textAutos[i])
                        {
                            textFeild=this.props.textAutos[i];
                        }

                    }
                    return(
                        <li key={i} >
                            <div {...props} className={"radio-btn "+((this.state.value&&this.state.value==child[this.props.valueField])?"checkedRadio":"")} onClick={this.onSelect.bind(this,child[this.props.valueField],child[this.props.textField])}><i>
                                <input type="radio"
                                       id={this.props.name+child[this.props.valueField]}
                                       value={child[this.props.valueField]}
                                       onChange={this.changeHandler}
                                    {...props}
                                >
                                </input>
                            </i></div><div className="radiotext">{textFeild}</div></li>
                    );})
            }


        }

        if(this.props.onlyline)
        {
            return (

                <div >
                    {
                        control
                    }
                </div>
            )
        }
        else
        {
            return (

                <ul className="checkul">
                    {
                        control
                    }
                </ul>
            )
        }


    }

});
module.exports=Radio;
